use Test::More;
use lib 't/test';
use Clean::Up;

is(Clean::Up::okay, 1, 'okay exits');
is(Clean::Up::not, 0, 'not exists that calls not_okay');
eval { Clean::Up::not_okay() }; 
like($@, qr/Undefined subroutine &Clean::Up::not_okay/, 'not_okay does not exists aka cleaned');
done_testing;
